@@ -17,8 +17,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifndef KACTIVITIES_MODELS_RESOURCE_MODEL_H
-#define KACTIVITIES_MODELS_RESOURCE_MODEL_H
+#ifndef KACTIVITIES_IMPORTS_RESOURCE_MODEL_H
+#define KACTIVITIES_IMPORTS_RESOURCE_MODEL_H
 
 // Qt
 #include <QObject>
@@ -35,15 +35,15 @@
 #include <memory>
 
 // Local
-#include <lib/core/controller.h>
-#include <lib/core/consumer.h>
-#include <lib/core/info.h>
+#include <lib/controller.h>
+#include <lib/consumer.h>
+#include <lib/info.h>
 
 class QModelIndex;
 class QDBusPendingCallWatcher;
 
 namespace KActivities {
-namespace Models {
+namespace Imports {
 
 /**
  * ResourceModel
@@ -153,7 +153,7 @@ public Q_SLOTS:
     QString resourceAt(int row) const;
 
 protected:
-    virtual bool lessThan(const QModelIndex &left, const QModelIndex &right) const Q_DECL_OVERRIDE;
+    bool lessThan(const QModelIndex &left, const QModelIndex &right) const Q_DECL_OVERRIDE;
 
 
 Q_SIGNALS:
@@ -195,6 +195,7 @@ private:
     mutable bool m_defaultItemsLoaded;
 
     void reloadData();
+    QString validateResource(const QString &resource) const;
 
     class LinkerService;
     std::shared_ptr<LinkerService> m_linker;
@@ -202,7 +203,8 @@ private:
     mutable KConfigGroup m_config;
 };
 
-} // namespace Models
+} // namespace Imports
 } // namespace KActivities
 
-#endif // KACTIVITIES_MODELS_RESOURCE_MODEL_H
+#endif // KACTIVITIES_IMPORTS_RESOURCE_MODEL_H
+
